{**********************************************************************}
{*		Initialization and startup routines for entire program					*}
{**********************************************************************}

unit Init;

interface

uses IniFiles, SysUtils, WinProcs, Dialogs, DB, Forms, AdPort, DBTables, Global;

function PreProgramStartUpOkay: Boolean;
procedure ApplicationShutDown;

implementation

function DBAliasOkay(IniFile: TIniFile): Boolean;
var DBLocation: string;
begin
	Result := True;

	DBLocation := IniFile.ReadString('Database', 'Location', '');

	if Length(DBLocation) = 0 then
	begin
		MessageDlg('Unable to find [Database] Location= entry in ' +
			CIniFileName + '. Run Setup utility.', mtError, [mbOK], 0);

		Result := False;
	end
	else
	begin
		{ Everything okay so far in initialization sequence }
		LoanDatabase := TDatabase.Create(nil);

		{ Create an application-local, Paradox DB alias }
		with LoanDatabase do
		begin
			DatabaseName:= CDatabaseName;
			DriverName:= 'STANDARD';
			Params.Clear;
			Params.Add('PATH=' + DBLocation);
		end;
	end;
end;

procedure SetupKeyTable;
begin
	KeyTable := TTable.Create(Application);

	with KeyTable do
	begin
		DatabaseName := CDatabaseName;			{ Set to local database alias }
		TableName := CKeyTableName;

		Open;
	end;

	bKeyTableHasBeenInitialized := True;
end;


{ Checks that all .INI file settings could be read and sets program globals }
function PreProgramStartUpOkay: Boolean;
var IniFile: TIniFile;
		pWindowsDir: PChar;
		aStr: string;
begin
	try
		pWindowsDir := StrAlloc(512);
		GetWindowsDirectory(pWindowsDir, 512);
		aStr := StrPas(pWindowsDir) + '\' + CIniFileName;
	finally
		StrDispose(pWindowsDir);
	end;

	Result := True;

	{ Make sure our .INI file exists and has proper settings in it }
	if FileExists(aStr) then
	begin
		try
			IniFile := TIniFile.Create(CIniFileName);

			if not DBAliasOkay(IniFile) then
				Result := False else

			SetupKeyTable;		{ Setup global key table variable }

			bAutoMaximizeForms := IniFile.ReadBool(CProgramOptionsSection,
				CAutoMaximizeFormsIdent, True);
		finally
			IniFile.Free;
		end;
	end
	else
	{ Get here if there's no .INI file at all in the Windows directory }
	begin
		MessageDlg(CIniFileName + ' not found.  Please run the Setup utility',
			mtError, [mbOK], 0);

		Result := False;
	end;
end;

{ This procedure should free all global variables and close all open database
	connections. }
procedure ApplicationShutDown;
begin
	{ Free global variables }
	LoanDatabase.Free;

	if bKeyTableHasBeenInitialized then
		KeyTable.Close;	{ Close down global key table }

	Application.Terminate;
end;

end.
